.. title: Welcome to Nikola
.. slug: welcome-to-nikola
.. date: 2012-03-30 23:00:00 UTC-03:00
.. tags: nikola, python, demo, blog
.. author: Roberto Alsina
.. link: https://getnikola.com/
.. description:
.. category: nikola

.. figure:: http://farm1.staticflickr.com/138/352972944_4f9d568680.jpg
   :target: http://farm1.staticflickr.com/138/352972944_4f9d568680_z.jpg?zz=1
   :class: thumbnail
   :alt: Nikola Tesla Corner by nicwest, on Flickr

If you can see this in a web browser, it means you managed to install Nikola,
and build a site using it. Congratulations!

Next steps:

* :doc:`Read the manual <handbook>`
* `Visit the Nikola website to learn more <https://getnikola.com>`__
* `See a demo photo gallery <link://gallery/demo>`__
* :doc:`See a demo listing <listings-demo>`
* :doc:`See a demo slideshow <slides-demo>`
* :doc:`See a demo of the Bootstrap theme <bootstrap-demo>`

Send feedback to info@getnikola.com!
